==> vue-progress-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dft-vue-2-opentiny/vue-renderless/progress/vue";
import { defineComponent, props, setup as _setup } from "@dft-vue-2-opentiny/vue-common";
import { iconClose, iconSuccess, iconError, iconYes, iconWarning } from "@dft-vue-2-opentiny/vue-icon";
import "@dft-vue-2-opentiny/vue-theme/progress/index.css";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["type", "percentage", "status", "strokeWidth", "textInside", "width", "showText", "color", "format"]),
  components: {
    IconClose: iconClose(),
    IconSuccess: iconSuccess(),
    IconError: iconError(),
    IconYes: iconYes(),
    IconWarning: iconWarning()
  },
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-progress",
    class: ["tiny-progress--" + _vm.type, _vm.status ? "is-" + _vm.status : "", {
      "tiny-progress--without-text": !_vm.showText,
      "tiny-progress--text-inside": _vm.textInside
    }],
    attrs: {
      "role": "progressbar",
      "aria-valuenow": _vm.percentage,
      "aria-valuemin": "0",
      "aria-valuemax": "100"
    }
  }, [_vm.type === "line" ? _c("div", {
    staticClass: "tiny-progress-bar"
  }, [_c("div", {
    staticClass: "tiny-progress-bar__outer",
    style: {
      height: _vm.state.strokeWidth + "px",
      borderRadius: _vm.state.strokeWidth / 2 + "px"
    }
  }, [_c("transition", {
    attrs: {
      "appear": "",
      "appear-class": "custom-appear-class"
    },
    on: {
      "before-appear": _vm.customBeforeAppearHook,
      "appear": _vm.customAppearHook,
      "after-appear": _vm.customAfterAppearHook
    }
  }, [_c("div", {
    staticClass: "tiny-progress-bar__inner",
    style: Object.assign({}, _vm.state.barStyle, {
      borderRadius: _vm.state.strokeWidth / 2 + "px"
    })
  }, [_vm.showText && _vm.textInside ? _c("div", {
    staticClass: "tiny-progress-bar__innerText"
  }, [_vm._v(" " + _vm._s(_vm.state.content) + " ")]) : _vm._e()])])], 1)]) : _c("div", {
    staticClass: "tiny-progress-circle",
    style: {
      height: _vm.state.width + "px",
      width: _vm.state.width + "px"
    }
  }, [_c("svg", {
    attrs: {
      "viewBox": "0 0 100 100"
    }
  }, [_c("path", {
    staticClass: "tiny-progress-circle__track",
    style: _vm.state.trailPathStyle,
    attrs: {
      "d": _vm.state.trackPath,
      "stroke": "#e5e9f2",
      "stroke-width": _vm.state.relativeStrokeWidth,
      "fill": "none"
    }
  }), _c("transition", {
    attrs: {
      "appear": "",
      "appear-class": "custom-appear-class"
    },
    on: {
      "before-appear": _vm.customBeforeAppearHook,
      "appear": _vm.customAppearHook,
      "after-appear": _vm.customAfterAppearHook
    }
  }, [_c("path", {
    staticClass: "tiny-progress-circle__path",
    style: _vm.state.circlePathStyle,
    attrs: {
      "d": _vm.state.trackPath,
      "stroke": _vm.state.stroke,
      "fill": "none",
      "stroke-linecap": "round",
      "stroke-width": _vm.percentage ? _vm.state.relativeStrokeWidth : 0
    }
  })])], 1)]), _vm.showText && !_vm.textInside ? _c("div", {
    staticClass: "tiny-progress__text",
    style: {
      fontSize: _vm.state.progressTextSize + "px"
    }
  }, [!_vm.status ? [_vm._v(" " + _vm._s(_vm.state.content) + " ")] : _c(_vm.state.iconClass, {
    tag: "component",
    staticClass: "tiny-svg-size"
  })], 2) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-progress-2.21.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/progress/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { iconClose, iconSuccess, iconError, iconYes, iconWarning } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/progress/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["type", "percentage", "status", "strokeWidth", "textInside", "width", "showText", "color", "format"]),
  components: {
    IconClose: iconClose(),
    IconSuccess: iconSuccess(),
    IconError: iconError(),
    IconYes: iconYes(),
    IconWarning: iconWarning()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-progress",
    class: ["tiny-progress--" + _vm.type, _vm.status ? "is-" + _vm.status : "", {
      "tiny-progress--without-text": !_vm.showText,
      "tiny-progress--text-inside": _vm.textInside
    }],
    attrs: {
      "role": "progressbar",
      "aria-valuenow": _vm.percentage,
      "aria-valuemin": "0",
      "aria-valuemax": "100"
    }
  }, [_vm.type === "line" ? _c("div", {
    staticClass: "tiny-progress-bar"
  }, [_c("div", {
    staticClass: "tiny-progress-bar__outer",
    style: {
      height: _vm.state.strokeWidth + "px",
      borderRadius: _vm.state.strokeWidth / 2 + "px"
    }
  }, [_c("transition", {
    attrs: {
      "appear": "",
      "appear-class": "custom-appear-class"
    },
    on: {
      "before-appear": _vm.customBeforeAppearHook,
      "appear": _vm.customAppearHook,
      "after-appear": _vm.customAfterAppearHook
    }
  }, [_c("div", {
    staticClass: "tiny-progress-bar__inner",
    style: Object.assign({}, _vm.state.barStyle, {
      borderRadius: _vm.state.strokeWidth / 2 + "px"
    })
  }, [_vm.showText && _vm.textInside ? _c("div", {
    staticClass: "tiny-progress-bar__innerText"
  }, [_vm._v(" " + _vm._s(_vm.state.content) + " ")]) : _vm._e()])])], 1)]) : _c("div", {
    staticClass: "tiny-progress-circle",
    style: {
      height: _vm.state.width + "px",
      width: _vm.state.width + "px"
    }
  }, [_c("svg", {
    attrs: {
      "viewBox": "0 0 100 100"
    }
  }, [_c("path", {
    staticClass: "tiny-progress-circle__track",
    style: _vm.state.trailPathStyle,
    attrs: {
      "d": _vm.state.trackPath,
      "stroke": "#e5e9f2",
      "stroke-width": _vm.state.relativeStrokeWidth,
      "fill": "none"
    }
  }), _c("transition", {
    attrs: {
      "appear": "",
      "appear-class": "custom-appear-class"
    },
    on: {
      "before-appear": _vm.customBeforeAppearHook,
      "appear": _vm.customAppearHook,
      "after-appear": _vm.customAfterAppearHook
    }
  }, [_c("path", {
    staticClass: "tiny-progress-circle__path",
    style: _vm.state.circlePathStyle,
    attrs: {
      "d": _vm.state.trackPath,
      "stroke": _vm.state.stroke,
      "fill": "none",
      "stroke-linecap": "round",
      "stroke-width": _vm.percentage ? _vm.state.relativeStrokeWidth : 0
    }
  })])], 1)]), _vm.showText && !_vm.textInside ? _c("div", {
    staticClass: "tiny-progress__text",
    style: {
      fontSize: _vm.state.progressTextSize + "px"
    }
  }, [!_vm.status ? [_vm._v(" " + _vm._s(_vm.state.content) + " ")] : _c(_vm.state.iconClass, {
    tag: "component",
    staticClass: "tiny-svg-size"
  })], 2) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
